# Python gestion des chaines de caractère

![tag](python)
![category](developpement)

il est assez simple en python d'imprimer des chaines de caractères par concatenation

```python
protocole = "https://"
nom_du_site = "Docstring"
extension = "fr"

url = protocole + "www." + nom_du_site + "." + extension
```

mais à lire ce n'est pas génial et si un élément n'est pas une chaine de caractère il faut gérer les exceptions.

Depuis python 3 on peut utiliser la fonction **format**

```python
age = 26
phrase = "J'ai {} ans".format(age)
```

et elle permet de faire des choses évolués

```python
prenom = "Pierre"
age = 26
langage = "Python"
phrase = "Je m'appelle {prenom} et j'ai {age} ans. {prenom} apprends le langage {langage}.".format(prenom=prenom,
                                                                                                   age=age,
                                                                                                   langage=langage)
```

Il existe une autre méthode utilisant des **f-string**. Elle permet de passer dans le string des fonctions de transformation

```python
protocole = "https://"
nom_du_site = "Docstring"
extension = "fr"

url = f"{protocole}www.{nom_du_site.lower()}.{extension}"  # https://www.docstring.fr
```

de plus on peut formatter notre texte avec des f-string

```python
nombre = 12

# Avec format
nombre_pad = "{:04d}".format(nombre)  # 0012

# Avec un f-string
nombre_pad = f"{nombre:04d}"  # 0012
```

Exemple d'utilisation

```python
import os
import collections
from copy import deepcopy
import csv

class TestA:

    def __init__(self, a):
        self.a = a
    
    def __str__(self):
        return "je suis {my.a}".format(my=self)

class TestB:

    def __init__(self, a):
        self.a = a
    
    def __str__(self):
        return f"je suis {self.a.upper()}"


a = TestA("fred")
print(a)
b = TestB("fred")
print(b)
```